@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -38,7 +38,8 @@ snmp_oid = {'default': {'hostname': '1.3.6.1.2.1.1.5.0',
 # Dict (key: OS short name) of dict (reg exp OID to human)
 # Windows:
 # http://msdn.microsoft.com/en-us/library/windows/desktop/ms724832%28v=vs.85%29.aspx
-snmp_to_human = {'windows': {'Windows Version 6.3': 'Windows 8.1 or Server 2012R2',
+snmp_to_human = {'windows': {'Windows Version 10.0': 'Windows 10 or Server 2016',
+                             'Windows Version 6.3': 'Windows 8.1 or Server 2012R2',
                              'Windows Version 6.2': 'Windows 8 or Server 2012',
                              'Windows Version 6.1': 'Windows 7 or Server 2008R2',
                              'Windows Version 6.0': 'Windows Vista or Server 2008',
@@ -62,7 +63,7 @@ def _linux_os_release():
             for line in f:
                 for key in keys:
                     if line.startswith(key):
-                        ashtray[key] = line.strip().split('=')[1][1:-1]
+                        ashtray[key] = re.sub(r'^"|"$', '', line.strip().split('=')[1])
     except (OSError, IOError):
         return pretty_name
 
@@ -70,7 +71,7 @@ def _linux_os_release():
         if 'NAME' in ashtray:
             pretty_name = ashtray['NAME']
         if 'VERSION_ID' in ashtray:
-            pretty_name += ' {0}'.format(ashtray['VERSION_ID'])
+            pretty_name += ' {}'.format(ashtray['VERSION_ID'])
 
     return pretty_name
 
@@ -82,82 +83,85 @@ class Plugin(GlancesPlugin):
     stats is a dict
     """
 
-    def __init__(self, args=None):
+    def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args)
+        super(Plugin, self).__init__(args=args, config=config)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
 
-        # Init the stats
-        self.reset()
-
-    def reset(self):
-        """Reset/init the stats."""
-        self.stats = {}
-
+    @GlancesPlugin._check_decorator
+    @GlancesPlugin._log_result_decorator
     def update(self):
         """Update the host/system info using the input method.
 
         Return the stats (dict)
         """
-        # Reset stats
-        self.reset()
+        # Init new stats
+        stats = self.get_init_value()
 
         if self.input_method == 'local':
             # Update stats using the standard system lib
-            self.stats['os_name'] = platform.system()
-            self.stats['hostname'] = platform.node()
-            self.stats['platform'] = platform.architecture()[0]
-            if self.stats['os_name'] == "Linux":
-                linux_distro = platform.linux_distribution()
-                if linux_distro[0] == '':
-                    self.stats['linux_distro'] = _linux_os_release()
+            stats['os_name'] = platform.system()
+            stats['hostname'] = platform.node()
+            stats['platform'] = platform.architecture()[0]
+            if stats['os_name'] == "Linux":
+                try:
+                    linux_distro = platform.linux_distribution()
+                except AttributeError:
+                    stats['linux_distro'] = _linux_os_release()
                 else:
-                    self.stats['linux_distro'] = ' '.join(linux_distro[:2])
-                self.stats['os_version'] = platform.release()
-            elif self.stats['os_name'].endswith('BSD'):
-                self.stats['os_version'] = platform.release()
-            elif self.stats['os_name'] == "Darwin":
-                self.stats['os_version'] = platform.mac_ver()[0]
-            elif self.stats['os_name'] == "Windows":
+                    if linux_distro[0] == '':
+                        stats['linux_distro'] = _linux_os_release()
+                    else:
+                        stats['linux_distro'] = ' '.join(linux_distro[:2])
+                stats['os_version'] = platform.release()
+            elif (stats['os_name'].endswith('BSD') or
+                  stats['os_name'] == 'SunOS'):
+                stats['os_version'] = platform.release()
+            elif stats['os_name'] == "Darwin":
+                stats['os_version'] = platform.mac_ver()[0]
+            elif stats['os_name'] == "Windows":
                 os_version = platform.win32_ver()
-                self.stats['os_version'] = ' '.join(os_version[::2])
+                stats['os_version'] = ' '.join(os_version[::2])
                 # if the python version is 32 bit perhaps the windows operating
                 # system is 64bit
-                if self.stats['platform'] == '32bit' and 'PROCESSOR_ARCHITEW6432' in os.environ:
-                    self.stats['platform'] = '64bit'
+                if stats['platform'] == '32bit' and 'PROCESSOR_ARCHITEW6432' in os.environ:
+                    stats['platform'] = '64bit'
             else:
-                self.stats['os_version'] = ""
+                stats['os_version'] = ""
             # Add human readable name
-            if self.stats['os_name'] == "Linux":
-                self.stats['hr_name'] = self.stats['linux_distro']
+            if stats['os_name'] == "Linux":
+                stats['hr_name'] = stats['linux_distro']
             else:
-                self.stats['hr_name'] = '{0} {1}'.format(
-                    self.stats['os_name'], self.stats['os_version'])
-            self.stats['hr_name'] += ' {0}'.format(self.stats['platform'])
+                stats['hr_name'] = '{} {}'.format(
+                    stats['os_name'], stats['os_version'])
+            stats['hr_name'] += ' {}'.format(stats['platform'])
 
         elif self.input_method == 'snmp':
             # Update stats using SNMP
             try:
-                self.stats = self.get_stats_snmp(
+                stats = self.get_stats_snmp(
                     snmp_oid=snmp_oid[self.short_system_name])
             except KeyError:
-                self.stats = self.get_stats_snmp(snmp_oid=snmp_oid['default'])
+                stats = self.get_stats_snmp(snmp_oid=snmp_oid['default'])
             # Default behavor: display all the information
-            self.stats['os_name'] = self.stats['system_name']
+            stats['os_name'] = stats['system_name']
             # Windows OS tips
             if self.short_system_name == 'windows':
                 for r, v in iteritems(snmp_to_human['windows']):
-                    if re.search(r, self.stats['system_name']):
-                        self.stats['os_name'] = v
+                    if re.search(r, stats['system_name']):
+                        stats['os_name'] = v
                         break
             # Add human readable name
-            self.stats['hr_name'] = self.stats['os_name']
+            stats['hr_name'] = stats['os_name']
+
+        # Update the stats
+        self.stats = stats
 
         return self.stats
 
-    def msg_curse(self, args=None):
+    def msg_curse(self, args=None, max_width=None):
         """Return the string to display in the curse interface."""
         # Init the return message
         ret = []
@@ -180,17 +184,17 @@ class Plugin(GlancesPlugin):
         ret.append(self.curse_add_line(msg, "TITLE"))
         # System info
         if self.stats['os_name'] == "Linux" and self.stats['linux_distro']:
-            msg = ' ({0} {1} / {2} {3})'.format(self.stats['linux_distro'],
-                                                self.stats['platform'],
-                                                self.stats['os_name'],
-                                                self.stats['os_version'])
+            msg = ' ({} {} / {} {})'.format(self.stats['linux_distro'],
+                                            self.stats['platform'],
+                                            self.stats['os_name'],
+                                            self.stats['os_version'])
         else:
             try:
-                msg = ' ({0} {1} {2})'.format(self.stats['os_name'],
-                                              self.stats['os_version'],
-                                              self.stats['platform'])
+                msg = ' ({} {} {})'.format(self.stats['os_name'],
+                                           self.stats['os_version'],
+                                           self.stats['platform'])
             except Exception:
-                msg = ' ({0})'.format(self.stats['os_name'])
+                msg = ' ({})'.format(self.stats['os_name'])
         ret.append(self.curse_add_line(msg, optional=True))
 
         # Return the message with decoration
